@@ -326,12 +326,17 @@ int main(int argc, const char **argv){
 
         //ポート番号入力のプロンプト
 	memset (buf, 0x20, 12);
-        while (memcmp (buf, "Port Number:", 12) != 0)
+	numrcv = recv(dstSocket, buf, 255, 0);
+        if (memcmp (buf, "Port Number:", 12) == 0)
 	{
-		numrcv = recv(dstSocket, buf, 255, 0);
        	 	buf[numrcv] = 0x00;
         	printf("%s\n",buf);
 	}
+	else 
+	{
+		printf ("Invalide CallSign or Password\n");
+		CloseSocket();
+	}
 
 	sprintf (buf, "%0d\0", ntohs(client_port));
 	//ポート番号の送信
@@ -366,7 +371,7 @@ int main(int argc, const char **argv){
 	while (1){
 		readOk = Mask;
 		timeout.tv_sec = 0;
-		timeout.tv_usec = 5000;
+		timeout.tv_usec = 5000;		/* 5 m Sec. */
 		switch (select (width, (fd_set *)&readOk, NULL, NULL, &timeout))
 		{
 	
